<?php

namespace Teknisa\CADEST\Services;

class TabelaPreco {

	protected $entityManager;

	public function __construct(\Doctrine\ORM\EntityManager $entityManager)  {
		$this->entityManager = $entityManager;
	}
	
	public function findProdTabPrec($params){
		 return $this->entityManager->getConnection()->fetchAll(self::FIND_PRODTABPREC, $params);
	}
	
	const FIND_PRODTABPREC = "
		SELECT
    TP.CDTABEPREC,
    TP.NMTABEPREC,
    TO_CHAR(TRUNC(TV.DTINIVGPREC), 'DD/MM/YYYY') AS DTINIVGPREC,
    TO_CHAR(TRUNC(TV.DTFINVGPREC), 'DD/MM/YYYY') AS DTFINVGPREC,
    TV.CDFILIAL,
    F.NMFILIAL,
    TP.NRORG,
    TP.CDTABEPREC
    || ' - '
    || TP.NMTABEPREC AS LABELTABPREC,
    TV.CDFILIAL
    || ' - '
    || F.NMFILIAL AS LABELUNIDADE
FROM
    TABEPREC   TP
    JOIN TABEVEND   TV ON TP.CDTABEPREC = TV.CDTABEPREC
                        AND TP.CDFILIAL = TV.CDFILIAL
                        AND TP.NRORG = TV.NRORG
    JOIN FILIAL     F ON TP.CDFILIAL = F.CDFILIAL
                     AND TV.CDFILIAL = F.CDFILIAL
                     AND TP.NRORG = F.NRORG
WHERE
    TV.DTINIVGPREC < TRUNC(SYSDATE)
    AND TV.DTFINVGPREC > TRUNC(SYSDATE)
    AND TP.NRORG = :NRORG
    AND ((INSTR(:CDFILIAL, TP.CDFILIAL) <> 0)
    OR :CDFILIAL = 'T')
    AND TV.CDTABEPREC
        || TV.DTINIVGPREC
        || TV.CDFILIAL NOT IN (
        SELECT
            T.CDTABEPREC
            || T.DTINIVGPREC
            || T.CDFILIAL
        FROM
            TABEVEND    T
            JOIN ITEMPRECO   IT ON IT.CDTABEPREC = T.CDTABEPREC
                                 AND IT.CDFILIAL = T.CDFILIAL
        WHERE
            IT.CDPRODUTO = :CDPRODUTO
    )
ORDER BY
    LABELUNIDADE
	";

	
	public function deleteProdTabPrec($params){
		foreach($params as $data){
			$conditions = array (
				":NRORG" => $data['NRORG'],
				":CDFILIAL" => $data['CDFILIAL'],
				":CDPRODUTO" => $data['CDPRODUTO'],
				":DTINIVGPREC" => $data['DTINIVGPREC']
				);
		 $this->entityManager->getConnection()->executeQuery(self::DELETE_ITEMPRECO, $conditions);
		}
		
		return true;
	}
	
	const DELETE_ITEMPRECO = "
	DELETE FROM ITEMPRECO WHERE CDFILIAL = :CDFILIAL AND NRORG = :NRORG AND CDPRODUTO = :CDPRODUTO AND DTINIVGPREC = :DTINIVGPREC";
	
	
	public function saveProdTabPrec($params){
		if($params['__is_new']){
			
			return $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECO, $params);
		} else {
			return $this->entityManager->getConnection()->executeQuery(self::UPDATE_ITEMPRECO, $params);
		}
	}
	
	const INSERT_ITEMPRECO = "
	INSERT INTO ITEMPRECO (
			CDPRODUTO,	NRORG,	CDFILIAL, CDTABEPREC,   
			DTINIVGPREC,	VRPRECITEM, CDPRPAITABPR, 
			VRCUSTITEM, VRPRECITEMCL, VRPRESUGITEM 
		) VALUES (
			:CDPRODUTO,	:NRORG,	:CDFILIAL, :CDTABEPREC,   
			:DTINIVGPREC, 	:VRPRECITEM, :CDPRPAITABPR, 
			:VRCUSTITEM, :VRPRECITEMCL, :VRPRESUGITEM 
			)";
			
	const UPDATE_ITEMPRECO = "
		UPDATE ITEMPRECO 
        SET CDPRODUTO = :CDPRODUTO,
            CDTABEPREC = :CDTABEPREC,
            VRPRECITEM = :VRPRECITEM,
            CDPRPAITABPR = :CDPRPAITABPR,
            VRCUSTITEM = :VRCUSTITEM,
            VRPRECITEMCL= :VRPRECITEMCL,
            VRPRESUGITEM= :VRPRESUGITEM
            
      WHERE CDPRODUTO = :CDPRODUTO AND
            CDFILIAL = :CDFILIAL AND  
            CDTABEPREC = :CDTABEPREC AND 
            NRORG = :NRORG";
			
		
}